@@ -28,7 +28,7 @@ def md2pdf(pdf_file_path, md_content=None, md_file_path=None,
 
     # Convert markdown to html
     raw_html = ''
-    extras = ['cuddled-lists', 'tables']
+    extras = ['cuddled-lists', 'tables', 'footnotes']
     if md_file_path:
         raw_html = markdown_path(md_file_path, extras=extras)
     elif md_content:
